import {apiUrl} from '../../env.js'
import axios from 'axios'

export const getAxiosConfig = () => {
    let config = {
        headers : {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        }
    }
    config.headers["Access-Token"] = sessionStorage.getItem('@portalmec/accessToken');
    config.headers.Client = sessionStorage.getItem('@portalmec/clientToken')
    config.headers.Uid = sessionStorage.getItem('@portalmec/uid')

    return config
}

function getAxiosConfigFromJSON () {
    let config = {
        headers : JSON.parse(sessionStorage.getItem('@portalmec/auth_headers'))
    }
    return config
}

function updateHeaders (newAccessToken) {
    sessionStorage.setItem('@portalmec/accessToken', newAccessToken)

    let auth_headers = JSON.parse(sessionStorage.getItem('@portalmec/auth_headers'))
    auth_headers['access-token'] = newAccessToken

    sessionStorage.setItem('@portalmec/auth_headers', JSON.stringify(auth_headers))
}

export const makeAxiosGetRequest = (url, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.get( (`${apiUrl}${url}`), config ).then(
        (response) => {

            if ( response.headers['access-token'] ) {
                updateHeaders(response.headers['access-token'])
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}

export const makeAxiosDeleteRequest = (url, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.delete( (`${apiUrl}${url}`), config ).then(
        (response) => {

            if ( response.headers['access-token'] ) {
                updateHeaders(response.headers['access-token'])
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}


export const makeAxiosPutRequest = (url, payload, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.put( (`${apiUrl}${url}`), payload, config ).then(
        (response) => {

            if ( response.headers['access-token'] ) {
                updateHeaders(response.headers['access-token'])
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}
